Learn R Programming

ThreeWay (version 1.1.4)

phi: Phi coefficient

Description

Computes the phi coefficients among columns of two matrices.

Usage

phi(a,b)

Value

p

Matrix containing the phi coefficients

Arguments

a

Vector or matrix of the same order of b

b

Vector or matrix of the same order of a

Author

Maria Antonietta Del Ferraro mariaantonietta.delferraro@yahoo.it
Henk A.L. Kiers h.a.l.kiers@rug.nl
Paolo Giordani paolo.giordani@uniroma1.it

References

L.R Tucker (1951). A method for synthesis of factor analysis studies. Personnel Research Section Report No. 984. Department of the Army, Washington, DC.

Examples

Run this code
X <- matrix(rnorm(6*3),ncol=3)
Y <- matrix(rnorm(6*3),ncol=3)
P <- phi(X,Y)

Run the code above in your browser using DataLab