powered by
Produces an array starting from its matricization with all the frontal slices of the array next to each other.
rarray(Xa, n, m, p)
Array leading to Xa
Xa
Matrix (or data.frame coerced to a matrix) containing the elements of the frontal slices of an array
Number of A-mode entities
A
Number of B-mode entities
B
Number of C-mode entities
C
Maria Antonietta Del Ferraro mariaantonietta.delferraro@yahoo.it Henk A.L. Kiers h.a.l.kiers@rug.nl Paolo Giordani paolo.giordani@uniroma1.it
H.A.L. Kiers (2000). Towards a standardized notation and terminology in multiway analysis. Journal of Chemometrics 14:105--122.
# matricized array (frontal slice) Xa <- matrix(1:8,nrow=2) X <- rarray(Xa, 2, 2, 2) # original array X
Run the code above in your browser using DataLab